
The possible risks to the application must be documented
-------

**Description:**

The information that is stored of the application and/or user 
activities needs to be documented, this will make it transparent where sensitive 
information is stored and why. 


**Solution:**

Create a section in the documentation of the project that defines the information 
that will be stored. This makes it easier to make estimations about critical parts
of your application which deserve extra attention. 
